## 0.20.1.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.20.1.1 (2022-10-24)

Remove `tree-sitter` from `pyright`'s exclude (#8946)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 0.20.1 (2022-09-06)

tree-sitter: add missing members (#8693)

## 0.20.0 (2022-08-17)

Add stubs for tree_sitter (#8533)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

